==> mapbender_3.0.8_ms4w.zip: ms4w/apps/mapbender-starter-v3.0.8/mapbender/src/Mapbender/WmsBundle/Component/Dimension.php <==
<?php

namespace Mapbender\WmsBundle\Component;

/**
 * Dimension class.
 *
 * @author Paul Schmidt
 */
class Dimension
{

    const NAME_TIME = 'time';
    const NAME_ELEVATION = 'elevation';
    const NAME_PREFIX = 'dim_';

    /**
     * ORM\Column(type="string", nullable=false)
     */
    public $name;

    /**
     * ORM\Column(type="string", nullable=false)
     */
    public $units;

    /**
     * ORM\Column(type="string", nullable=true)
     */
    public $unitSymbol;

    /**
     * ORM\Column(type="string", nullable=true)
     */
    public $default;

    /**
     * ORM\Column(type="boolean", nullable=true)
     */
    public $multipleValues = false;

    /**
     * ORM\Column(type="boolean", nullable=true)
     */
    public $nearestValue = false;

    /**
     * ORM\Column(type="boolean", nullable=true)
     */
    public $current = false;

    /**
     * ORM\Column(type="string", nullable=true)
     */
    public $extent;

    /**
     * Set name
     *
     * @param string $value
     */
    public function setName($value)
    {
        $this->name = $value;
    }

    /**
     * Get name
     *
     * @return string
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     * Set units
     *
     * @param string $value
     */
    public function setUnits($value)
    {
        $this->units = $value;
    }

    /**
     * Get units
     *
     * @return string
     */
    public function getUnits()
    {
        return $this->units;
    }

    /**
     * Set unitSymbol
     *
     * @param string $value
     */
    public function setUnitSymbol($value)
    {
        $this->unitSymbol = $value;
    }

    /**
     * Get unitSymbol
     *
     * @return string
     */
    public function getUnitSymbol()
    {
        return $this->unitSymbol;
    }

    /**
     * Set default
     *
     * @param string $value
     */
    public function setDefault($value)
    {
        $this->default = $value;
    }

    /**
     * Get default
     *
     * @return string|null
     */
    public function getDefault()
    {
        return $this->default;
    }

    /**
     * Set multipleValues
     *
     * @param boolean $value
     */
    public function setMultipleValues($value)
    {
        if (is_bool($value)) {
            $this->multipleValues = $value;
        } else {
            $this->multipleValues = (boolean) $value;
        }
    }

    /**
     * Get multipleValues
     *
     * @return boolean
     */
    public function getMultipleValues()
    {
        return $this->multipleValues;
    }

    /**
     * Set nearestValue
     *
     * @param boolean $value
     */
    public function setNearestValue($value)
    {
        if (is_bool($value)) {
            $this->nearestValue = $value;
        } else {
            $this->nearestValue = (boolean) $value;
        }
    }

    /**
     * Get nearestValue
     *
     * @return boolean
     */
    public function getNearestValue()
    {
        return $this->nearestValue;
    }

    /**
     * Set current
     *
     * @param boolean $value
     */
    public function setCurrent($value)
    {
        if (is_bool($value)) {
            $this->current = $value;
        } else {
            $this->current = (boolean) $value;
        }
    }

    /**
     * Get current
     *
     * @return boolean
     */
    public function getCurrent()
    {
        return $this->current;
    }

    /**
     * Set extent
     *
     * @param string $value
     */
    public function setExtent($value)
    {
        $this->extent = $value;
    }

    /**
     * Get extent
     *
     * @return Dimension
     */
    public function getExtent()
    {
        return $this->extent;
    }

    /**
     * Generates a GET parameter name for this dimension.
     * @return string parameter name
     */
    public function getParameterName()
    {
        if (strtolower($this->name) === self::NAME_TIME) {
            return self::NAME_TIME;
        } elseif (strtolower($this->name) === self::NAME_ELEVATION) {
            return self::NAME_ELEVATION;
        } else {
            return self::NAME_PREFIX . $this->name;
        }
    }
}

==> mapbender_3.2.4_ms4w.zip: ms4w/apps/mapbender-starter-v3.2.4/mapbender/src/Mapbender/WmsBundle/Component/Dimension.php <==
<?php

namespace Mapbender\WmsBundle\Component;

/**
 * @author Paul Schmidt
 */
class Dimension
{
    const NAME_TIME = 'time';
    const NAME_ELEVATION = 'elevation';
    const NAME_PREFIX = 'dim_';

    /** @var string|null */
    public $name;
    /** @var string|null */
    public $units;
    /** @var string|null */
    public $unitSymbol;
    /** @var string|null */
    public $default;
    /** @var bool */
    public $multipleValues = false;
    /** @var bool */
    public $nearestValue = false;
    /** @var bool */
    public $current = false;
    /** @var string|null */
    public $extent;

    /**
     * @param string|null $value
     */
    public function setName($value)
    {
        $this->name = $value;
    }

    /**
     * @return string|null
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     * @param string|null $value
     */
    public function setUnits($value)
    {
        $this->units = $value;
    }

    /**
     * @return string|null
     */
    public function getUnits()
    {
        return $this->units;
    }

    /**
     * @param string|null $value
     */
    public function setUnitSymbol($value)
    {
        $this->unitSymbol = $value;
    }

    /**
     * @return string|null
     */
    public function getUnitSymbol()
    {
        return $this->unitSymbol;
    }

    /**
     * @param string|null $value
     */
    public function setDefault($value)
    {
        $this->default = $value;
    }

    /**
     * @return string|null
     */
    public function getDefault()
    {
        return $this->default;
    }

    /**
     * @param boolean $value
     */
    public function setMultipleValues($value)
    {
        $this->multipleValues = !!$value;
    }

    /**
     * @return boolean
     */
    public function getMultipleValues()
    {
        return $this->multipleValues;
    }

    /**
     * @param boolean $value
     */
    public function setNearestValue($value)
    {
        $this->nearestValue = !!$value;
    }

    /**
     * @return boolean
     */
    public function getNearestValue()
    {
        return $this->nearestValue;
    }

    /**
     * @param boolean $value
     */
    public function setCurrent($value)
    {
        $this->current = !!$value;
    }

    /**
     * @return boolean
     */
    public function getCurrent()
    {
        return $this->current;
    }

    /**
     * @param string|null $value
     */
    public function setExtent($value)
    {
        $this->extent = $value;
    }

    /**
     * @return string|null
     */
    public function getExtent()
    {
        return $this->extent;
    }

    /**
     * Generates a GET parameter name for this dimension.
     * @return string
     */
    public function getParameterName()
    {
        if (strtolower($this->name) === self::NAME_TIME) {
            return self::NAME_TIME;
        } elseif (strtolower($this->name) === self::NAME_ELEVATION) {
            return self::NAME_ELEVATION;
        } else {
            return self::NAME_PREFIX . $this->name;
        }
    }
}
